Crate kcode_k1_access_profile_wire

Crate kcode_k1_access_profile_wire 

Structs

AuthorizationProfile
GroupId
ModelId
ProfileId
ProfileName
An exact, validated display name for a saved profile.
ProfileOperation
TxId
UserId

Enums

ProfileMutation
ProfileOwner
ProfileViewer

Functions

decode_profile
Decodes a complete canonical version 1 authorization profile.
encode_operation
encode_profile
Encodes an authorization profile in the canonical version 1 format.
parse_operation

Type Aliases

OperationId