encode_profile

Function encode_profile 

pub fn encode_profile(profile: &AuthorizationProfile) -> Result<Vec<u8>, String>
Encodes an authorization profile in the canonical version 1 format.

Owners and viewers are emitted in the normalized order exposed by the profile. An error is returned if either count cannot be represented by the format’s big-endian u32 count.